@@ -22,13 +22,14 @@ class PreprocessDatasets:
         relative directory where to store the downloaded files (e.g. './' current dir, '../' parent dir)
     """
 
-    def __init__(self, dataset, input_dir='./', top=500):
+    def __init__(self, dataset, input_dir='./', top=500, test_size=None):
         if dataset == 'm5':
             dataset = dataset.capitalize()
         self.dataset = dataset
         self.input_dir = input_dir
         self.api = 'http://www.machinelearningtimeseries.com/apidownload/'
         self.top = top
+        self.test_size = test_size
         self._create_directories()
 
     def _create_directories(self):
@@ -58,6 +59,8 @@ class PreprocessDatasets:
         if not path:
             return {}
         prison = pd.read_csv(path, sep=",")
+        if self.test_size:
+            prison = prison[:self.test_size]
 
         prison = prison.drop('Unnamed: 0', axis =1)
         prison['t'] = prison['t'].astype('datetime64[ns]')
@@ -82,6 +85,8 @@ class PreprocessDatasets:
         if not path:
             return {}
         tourism = pd.read_csv(path, sep=",")
+        if self.test_size:
+            tourism = tourism[:self.test_size]
 
         tourism['t'] = tourism['Date'].astype('datetime64[ns]')
         tourism = tourism.drop('Date', axis=1)
@@ -112,6 +117,10 @@ class PreprocessDatasets:
         cal = pd.read_csv(f'{INPUT_DIR}/calendar.csv')
         stv = pd.read_csv(f'{INPUT_DIR}/sales_train_validation.csv')
 
+        # M5 is too big to fit into memory, using test_size for testing purposes
+        if self.test_size:
+            stv = stv[:self.test_size]
+
         # Transform column wide days to single column
         stv = stv.melt(list(stv.columns[:6]), var_name='day', value_vars=list(stv.columns[6:]), ignore_index=True)
 
@@ -176,6 +185,8 @@ class PreprocessDatasets:
         if not path:
             return {}
         police = pd.read_excel(path)
+        if self.test_size:
+            police = police[:self.test_size]
 
         police = police.drop(['RMSOccurrenceHour', 'StreetName', 'Suffix', 'NIBRSDescription', 'Premise'], axis=1)
         police.columns = ['Id', 'Date', 'Crime', 'Count', 'Beat', 'Block', 'Street', 'City', 'ZIP']
